var ActivityRecognitionResult = com.google.android.gms.location.ActivityRecognitionResult;
var DetectedActivity = com.google.android.gms.location.DetectedActivity;
import { getAndroidMediumResRecognizer, } from "./recognizer.android";
import { activityTypeToHumanActivity, elapsedRealtimeToDate, } from "../../utils.android";
export class AndroidActivityUpdateReceiver {
    onReceive(context, intent) {
        if (!ActivityRecognitionResult.hasResult(intent)) {
            return;
        }
        const result = ActivityRecognitionResult.extractResult(intent);
        const recognizer = getAndroidMediumResRecognizer();
        const mostProbableActivity = result.getMostProbableActivity();
        if (mostProbableActivity.getType() === DetectedActivity.UNKNOWN) {
            return;
        }
        const activityUpdate = {
            type: activityTypeToHumanActivity(mostProbableActivity.getType()),
            confidence: mostProbableActivity.getConfidence() / 100.0,
            timestamp: elapsedRealtimeToDate(result.getElapsedRealtimeMillis() * 1e6),
        };
        recognizer.onRecognitionResult(activityUpdate).catch((err) => {
            console.error(`MediumResRecognizer. Recognition error: ${err}`);
        });
    }
}
let _updateReceiver;
export function getAndroidActivityUpdateReceiver() {
    if (!_updateReceiver) {
        _updateReceiver = new AndroidActivityUpdateReceiver();
    }
    return _updateReceiver;
}
//# sourceMappingURL=receiver.android.js.map