import { AbstractActivityRecognizer } from "../../abstract-recognizer";
import { recognizersStateStoreDb, } from "../../state/store";
import { RecognizerCallbackManager } from "../../callback-manager";
import { Resolution, Transition } from "../../../index";
import { AndroidMediumResRecognizerManager } from "./manager.android";
export class AndroidMediumResRecognizer extends AbstractActivityRecognizer {
    constructor(recognizerState, callbackManager, recognitionManager) {
        super(Resolution.MEDIUM, recognizerState, callbackManager, recognitionManager);
    }
    async onRecognitionResult(result) {
        const lastActivity = await this.recognizerState.getLastActivity(this.recognizerType);
        if (lastActivity === result.type) {
            return;
        }
        if (lastActivity) {
            this.callbackManager.notifyAll({
                type: lastActivity,
                transition: Transition.ENDED,
                timestamp: result.timestamp,
            });
        }
        this.callbackManager.notifyAll({
            type: result.type,
            transition: Transition.STARTED,
            confidence: result.confidence,
            timestamp: result.timestamp,
        });
        await this.recognizerState.updateLastActivity(this.recognizerType, result.type);
    }
}
let _instance;
export function getAndroidMediumResRecognizer() {
    if (!_instance) {
        _instance = new AndroidMediumResRecognizer(recognizersStateStoreDb, new RecognizerCallbackManager(), new AndroidMediumResRecognizerManager());
    }
    return _instance;
}
//# sourceMappingURL=recognizer.android.js.map